@@ -7,10 +7,11 @@ from logging import Handler
 
 from six import string_types, text_type
 
-import logstash_async
+from logstash_async.constants import constants
 from logstash_async.formatter import LogstashFormatter
 from logstash_async.utils import import_string, safe_log_via_print
 from logstash_async.worker import LogProcessingWorker
+import logstash_async
 
 
 class ProcessingError(Exception):
@@ -22,6 +23,7 @@ class AsynchronousLogstashHandler(Handler):
     :param host: The host of the logstash server, required.
     :param port: The port of the logstash server, required.
     :param database_path: The path to the file containing queued events, required.
+                          Use None to use a in-memory cache.
     :param transport: Callable or path to a compatible transport class.
     :param ssl_enable: Should SSL be enabled for the connection? Default is False.
     :param ssl_verify: Should the server's SSL certificate be verified?
@@ -29,7 +31,7 @@ class AsynchronousLogstashHandler(Handler):
     :param certfile: The path to client side SSL certificate file (default is None).
     :param ca_certs: The path to the file containing recognized CA certificates.
     :param enable: Flag to enable log processing (default is True, disabling
-                  might be handy for local testing, etc.)
+                   might be handy for local testing, etc.)
     :param event_ttl: Amount of time in seconds to wait before expiring log messages in
                       the database. (Given in seconds. Default is None, and disables this feature)
     """
@@ -88,6 +90,7 @@ class AsynchronousLogstashHandler(Handler):
             self._transport = transport_class(
                 host=self._host,
                 port=self._port,
+                timeout=constants.SOCKET_TIMEOUT,
                 ssl_enable=self._ssl_enable,
                 ssl_verify=self._ssl_verify,
                 keyfile=self._keyfile,
